import cyrtranslit
import ping, socket
import time

from pynput.keyboard import Key, Controller

def LANGRusToCyrilik(TextRUS):
    TextRUS = str(TextRUS).decode('cp1251')
    TextRUS = unicode(TextRUS).encode('utf-8')
    TextCyrylik = cyrtranslit.to_latin(TextRUS, 'ru')

    return TextCyrylik

def una_autorefresh(self):
        keyb = Controller()

        keyb.press(Key.alt)
        keyb.press(Key.tab)
        keyb.release(Key.alt)
        keyb.release(Key.tab)

        time.sleep(0.5)
        keyb.press(Key.alt)
        keyb.press('r')
        keyb.release(Key.alt)
        keyb.release('r')
        keyb.press(Key.down)
        keyb.release(Key.down)
        keyb.press(Key.up)
        keyb.release(Key.up)


def ping_addr(hostname):
    msg_except = None
    try:
        ip_res = ping.do_one(hostname, timeout=2, psize=3)
        if ip_res == None:
            res = 1
        else:
            res = 0
        return res, msg_except
    except socket.error, e:
        print("Ping error:", e)
        msg_except = "Ping error:" + str(e)
        return -1, msg_except



import smtplib
import imaplib
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from email.mime.base import MIMEBase
from email import encoders
import os.path
import UNA_Support.CustomException as Except

class Mail:
    """
    Transmiterea mesajelor electronice

    Transmission of electronic messages
    """

    def __init__(self):
        """
        Initializarea datelor pentru transmiterea mesajului:
         - SMTPServer: Tipul serverului de transmitere (mail.ru, gmal.com)
         - email: addresa electronica expediator
         - password: parola expediator
         - send_to_email: addresa electronica destinatar
         - subject: subiectul mesajului
         - message: textul mesajului
         - file_location: calea catre fisierul atasat la mesaj

         Initialize the data for sending the message:
         - SMTPServer: Transmission server type (mail.ru, gmal.com)
         - email: sender's email address
         - password: the sender password
         - send_to_email: recipient's email address
         - subject: the subject of the message
         - message: the text of the message
         - file_location: the path to the file attached to the message
        """

        self.SMTPServer = 'Mail.ru'
        self.email = None
        self.password = None
        self.send_to_email = None
        self.subject = None
        self.message = None
        self.file_location = None
        self.mail_CC = None
        self.check_send = False

    def MailRuSmtplib(self, msg, toaddrs):
        """
        Expedierea mesajului prin serverul mail.ru

        Sending the message through the mail.ru server
        """

        server = smtplib.SMTP_SSL('smtp.mail.ru', 465)
        server.login(self.email, self.password)
        text = msg.as_string()
        server.sendmail(self.email, toaddrs, text)
        server.quit()

    def GMailSmtplib(self, msg, toaddrs):
        """
        Expedierea mesajului prin serverul Gmail.com

        Send the message through the Gmail.com server
        """

        server = smtplib.SMTP('smtp.gmail.com', 587)
        server.ehlo()
        server.starttls()
        server.login(self.email, self.password)
        text = msg.as_string()
        server.sendmail(self.email, toaddrs, text)
        server.quit()

    def UNAmdSmtplib(self, msg, toaddrs):
        """
        Expedierea mesajului prin serverul mail.una.md

        Sending the message through the mail.una.md server
        """

        server = smtplib.SMTP('mail.una.md')
        server.ehlo()
        server.login(self.email, self.password)
        text = msg.as_string()
        server.sendmail(self.email, toaddrs, text)
        server.quit()

    def SendMail(self):
        """
        Transmiterea mesajului prin serverul indicat de utilizator in parametrul SMTPServer

        Transmission of the message through the server indicated by the user in the SMTPServer parameter
        """

        try:
            msg = MIMEMultipart()
            toaddrs = []
            if self.email == None: raise Except.EMailIsNone
            if self.password == None: raise Except.PasswordIsNone
            if self.send_to_email == None: raise Except.ToEMailIsNone
            if self.subject == None: raise Except.SubjectIsNone
            if self.message == None: raise Except.MessageIsNone
            msg['From'] = self.email
            msg['To'] = ", ".join(self.send_to_email)
            msg['Subject'] = self.subject

            for i in self.send_to_email:
                toaddrs.append(i)

            if self.mail_CC != None:
                msg['cc'] = ", ".join(self.mail_CC)
                for i in self.mail_CC:
                    toaddrs.append(i)

            msg.attach(MIMEText(self.message, 'plain'))

            # Setup the attachment
            if self.file_location != None:
                filename = os.path.basename(self.file_location)
                attachment = open(self.file_location, "rb")
                part = MIMEBase('application', 'octet-stream')
                part.set_payload(attachment.read())
                encoders.encode_base64(part)
                part.add_header('Content-Disposition', "attachment; filename= %s" % filename)

                # Attach the attachment to the MIMEMultipart object
                msg.attach(part)

            if self.SMTPServer == 'Mail.ru':
                self.MailRuSmtplib(msg, toaddrs)
            elif self.SMTPServer == 'GMail.com':
                self.GMailSmtplib(msg, toaddrs)
            elif self.SMTPServer == 'una.md':
                self.UNAmdSmtplib(msg, toaddrs)
            else:
                raise Except.SMTPServerNotRegister

            self.check_send = True
        except Except.EMailIsNone:
            result = "EMail None"
            print(result)
        except Except.PasswordIsNone:
            result = "Password None"
            print(result)
        except Except.ToEMailIsNone:
            result = "Email Receiver None"
            print(result)
        except Except.SubjectIsNone:
            result = "Subject message None"
            print(result)
        except Except.MessageIsNone:
            result = "Message None"
            print(result)
        except Except.FileLocationIsNone:
            result = "Attachment file location None"
            print(result)
        except smtplib.SMTPAuthenticationError as ex:
            result = "Error Authentication" + str(ex)
            print(result)
        except Except.SMTPServerNotRegister:
            result = self.SMTPServer + " server does not exist"
            print(result)
        else:
            result = "Message sent successfully"
            print(result)

        return result



# define Python user-defined exceptions

# Exceptions for Mail.py library ===============================
class Error(Exception):
   """Base class for other exceptions"""
   pass
class ValueIsNone(Error):
   """Raised when this value is None"""
   pass

class EMailIsNone(Error):
   """Raised EMail value is None"""
   pass

class PasswordIsNone(Error):
   """Raised password value is None"""
   pass
class ToEMailIsNone(Error):
   """Raised ToEMail value is None"""
   pass
class SubjectIsNone(Error):
   """Raised subject value is None"""
   pass
class MessageIsNone(Error):
   """Raised EMail value is None"""
   pass
class FileLocationIsNone(Error):
   """Raised FileLocation_location value is None"""
   pass
class SMTPServerNotRegister(Error):
   """Raised SMTP Server Not Register"""
   pass
# =================================================================


# -*- coding: utf-8 -*-
# Created by Nicolae Gaidarji at 08.07.2020
import os
try:
    from configparser import ConfigParser
except ImportError:
    from ConfigParser import ConfigParser  # ver. < 3.0


class CFG:
    """
    Crearea fisierului cu setari *.ini

    Creating the *.ini settings file

    ex:
        config = CFG(CurentPath + '\\setup.ini')

        config.conf.add_section('DB TNS')
        config.create_cfg_file()
    """
    def __init__(self, file):
        self.conf = ConfigParser()
        self.writepath = file
        self.msg_except = None

    def create_cfg_file(self):
        if os.path.exists(self.writepath):
            self.conf.read(self.writepath)
        else:
            self.write_cfg_filee()

    def write_cfg_filee(self):
        self.msg_except  = None
        try:
            with open(self.writepath, 'w') as f:
                self.conf.write(f)
        except Exception as ex:
            self.msg_except = str(ex)




import os

from datetime import *

class Log:

    def __init__(self, filename, path):
        date_now = datetime.now().strftime("%Y%m%d")
        self.filename = path + '\\' + date_now + '_' + filename + '.log'
        try:
            os.makedirs(path)
        except:
            pass

    def info(self, text):
        date_now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        f = open(self.filename, "a")
        f.write(date_now + ': INFO -     ' +str(text) + '\n')
        f.close()

    def error(self, text):
        date_now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        f = open(self.filename, "a")
        f.write(date_now + ': ERROR -     ' +str(text) + '\n')
        f.close()

    def start(self, text):
        date_now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        f = open(self.filename, "a")
        f.write(date_now + ': START - ' + str(text) + '\n')
        f.close()

    def end(self, text):
        date_now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        f = open(self.filename, "a")
        f.write(date_now + ': END - ' + str(text) + '\n\n')
        f.close()

    def text_tab(self, text):
        f = open(self.filename, "a")
        f.write('\t\t\t\t\t\t' +str(text) + '\n')
        f.close()

    def empy_line(self):
        f = open(self.filename, "a")
        f.write('\n')
        f.close()
